==> amarok-2.6.0-arm-1.tgz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/doc/HTML/pt_BR/amarok ; rm -rf common )
( cd usr/doc/HTML/pt_BR/amarok ; ln -sf /usr/share/doc/HTML/pt_BR/common common )
( cd usr/doc/HTML/pt/amarok ; rm -rf common )
( cd usr/doc/HTML/pt/amarok ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/doc/HTML/es/amarok ; rm -rf common )
( cd usr/doc/HTML/es/amarok ; ln -sf /usr/share/doc/HTML/es/common common )
( cd usr/doc/HTML/de/amarok ; rm -rf common )
( cd usr/doc/HTML/de/amarok ; ln -sf /usr/share/doc/HTML/de/common common )
( cd usr/doc/HTML/en/amarok ; rm -rf common )
( cd usr/doc/HTML/en/amarok ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/nl/amarok ; rm -rf common )
( cd usr/doc/HTML/nl/amarok ; ln -sf /usr/share/doc/HTML/nl/common common )
( cd usr/doc/HTML/ru/amarok ; rm -rf common )
( cd usr/doc/HTML/ru/amarok ; ln -sf /usr/share/doc/HTML/ru/common common )
( cd usr/doc/HTML/et/amarok ; rm -rf common )
( cd usr/doc/HTML/et/amarok ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/doc/HTML/sv/amarok ; rm -rf common )
( cd usr/doc/HTML/sv/amarok ; ln -sf /usr/share/doc/HTML/sv/common common )
( cd usr/doc/HTML/uk/amarok ; rm -rf common )
( cd usr/doc/HTML/uk/amarok ; ln -sf /usr/share/doc/HTML/uk/common common )
( cd usr/lib ; rm -rf libamarokocsclient.so )
( cd usr/lib ; ln -sf libamarokocsclient.so.4 libamarokocsclient.so )
( cd usr/lib ; rm -rf libamaroklib.so )
( cd usr/lib ; ln -sf libamaroklib.so.1 libamaroklib.so )
( cd usr/lib ; rm -rf libamaroklib.so.1 )
( cd usr/lib ; ln -sf libamaroklib.so.1.0.0 libamaroklib.so.1 )
( cd usr/lib ; rm -rf libamarokcore.so.1 )
( cd usr/lib ; ln -sf libamarokcore.so.1.0.0 libamarokcore.so.1 )
( cd usr/lib ; rm -rf libamarok-transcoding.so )
( cd usr/lib ; ln -sf libamarok-transcoding.so.1 libamarok-transcoding.so )
( cd usr/lib ; rm -rf libamarokocsclient.so.4 )
( cd usr/lib ; ln -sf libamarokocsclient.so.4.8.0 libamarokocsclient.so.4 )
( cd usr/lib ; rm -rf libamarokpud.so )
( cd usr/lib ; ln -sf libamarokpud.so.1 libamarokpud.so )
( cd usr/lib ; rm -rf libamarokcore.so )
( cd usr/lib ; ln -sf libamarokcore.so.1 libamarokcore.so )
( cd usr/lib ; rm -rf libamarok-sqlcollection.so.1 )
( cd usr/lib ; ln -sf libamarok-sqlcollection.so.1.0.0 libamarok-sqlcollection.so.1 )
( cd usr/lib ; rm -rf libamarok-sqlcollection.so )
( cd usr/lib ; ln -sf libamarok-sqlcollection.so.1 libamarok-sqlcollection.so )
( cd usr/lib ; rm -rf libamarokpud.so.1 )
( cd usr/lib ; ln -sf libamarokpud.so.1.0.0 libamarokpud.so.1 )
( cd usr/lib ; rm -rf libamarok-transcoding.so.1 )
( cd usr/lib ; ln -sf libamarok-transcoding.so.1.0.0 libamarok-transcoding.so.1 )

==> amarok-2.8.0-arm-1.tgz: install/doinst.sh <==

if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi

( cd usr/doc/HTML/pt_BR/amarok ; rm -rf common )
( cd usr/doc/HTML/pt_BR/amarok ; ln -sf /usr/share/doc/HTML/pt_BR/common common )
( cd usr/doc/HTML/et/amarok ; rm -rf common )
( cd usr/doc/HTML/et/amarok ; ln -sf /usr/share/doc/HTML/et/common common )
( cd usr/doc/HTML/es/amarok ; rm -rf common )
( cd usr/doc/HTML/es/amarok ; ln -sf /usr/share/doc/HTML/es/common common )
( cd usr/doc/HTML/pt/amarok ; rm -rf common )
( cd usr/doc/HTML/pt/amarok ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/doc/HTML/en/amarok ; rm -rf common )
( cd usr/doc/HTML/en/amarok ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/uk/amarok ; rm -rf common )
( cd usr/doc/HTML/uk/amarok ; ln -sf /usr/share/doc/HTML/uk/common common )
( cd usr/doc/HTML/sv/amarok ; rm -rf common )
( cd usr/doc/HTML/sv/amarok ; ln -sf /usr/share/doc/HTML/sv/common common )
( cd usr/doc/HTML/ru/amarok ; rm -rf common )
( cd usr/doc/HTML/ru/amarok ; ln -sf /usr/share/doc/HTML/ru/common common )
( cd usr/doc/HTML/de/amarok ; rm -rf common )
( cd usr/doc/HTML/de/amarok ; ln -sf /usr/share/doc/HTML/de/common common )
( cd usr/doc/HTML/nl/amarok ; rm -rf common )
( cd usr/doc/HTML/nl/amarok ; ln -sf /usr/share/doc/HTML/nl/common common )
( cd usr/lib ; rm -rf libamarokocsclient.so.4 )
( cd usr/lib ; ln -sf libamarokocsclient.so.4.10.5 libamarokocsclient.so.4 )
( cd usr/lib ; rm -rf libamarokshared.so.1 )
( cd usr/lib ; ln -sf libamarokshared.so.1.0.0 libamarokshared.so.1 )
( cd usr/lib ; rm -rf libamarok-sqlcollection.so )
( cd usr/lib ; ln -sf libamarok-sqlcollection.so.1 libamarok-sqlcollection.so )
( cd usr/lib ; rm -rf libamaroklib.so )
( cd usr/lib ; ln -sf libamaroklib.so.1 libamaroklib.so )
( cd usr/lib ; rm -rf libamarokcore.so )
( cd usr/lib ; ln -sf libamarokcore.so.1 libamarokcore.so )
( cd usr/lib ; rm -rf libamarok-transcoding.so.1 )
( cd usr/lib ; ln -sf libamarok-transcoding.so.1.0.0 libamarok-transcoding.so.1 )
( cd usr/lib ; rm -rf libamarok-transcoding.so )
( cd usr/lib ; ln -sf libamarok-transcoding.so.1 libamarok-transcoding.so )
( cd usr/lib ; rm -rf libamarokshared.so )
( cd usr/lib ; ln -sf libamarokshared.so.1 libamarokshared.so )
( cd usr/lib ; rm -rf libamarok-sqlcollection.so.1 )
( cd usr/lib ; ln -sf libamarok-sqlcollection.so.1.0.0 libamarok-sqlcollection.so.1 )
( cd usr/lib ; rm -rf libamarokpud.so.1 )
( cd usr/lib ; ln -sf libamarokpud.so.1.0.0 libamarokpud.so.1 )
( cd usr/lib ; rm -rf libamarokpud.so )
( cd usr/lib ; ln -sf libamarokpud.so.1 libamarokpud.so )
( cd usr/lib ; rm -rf libamaroklib.so.1 )
( cd usr/lib ; ln -sf libamaroklib.so.1.0.0 libamaroklib.so.1 )
( cd usr/lib ; rm -rf libamarokcore.so.1 )
( cd usr/lib ; ln -sf libamarokcore.so.1.0.0 libamarokcore.so.1 )
( cd usr/lib ; rm -rf libamarokocsclient.so )
( cd usr/lib ; ln -sf libamarokocsclient.so.4 libamarokocsclient.so )
